@@ -4,14 +4,17 @@ Shape Reducer HDBSCAN
 This module provides functions to cluster shapes extracted with
 :mod:`panoptes_aggregation.extractors.shape_extractor`.
 '''
+import numpy as np
+
+from hdbscan import HDBSCAN
 from collections import OrderedDict
 from .reducer_wrapper import reducer_wrapper
 from .subtask_reducer_wrapper import subtask_wrapper
 from ..shape_tools import SHAPE_LUT
 from .shape_process_data import process_data, DEFAULTS_PROCESS
 from .shape_metric import get_shape_metric_and_avg
-import numpy as np
-from hdbscan import HDBSCAN
+from .shape_metric_IoU import IoU_metric, average_shape_IoU
+
 
 DEFAULTS = {
     'min_cluster_size': {'default': 5, 'type': int},
@@ -20,7 +23,8 @@ DEFAULTS = {
     'leaf_size': {'default': 40, 'type': int},
     'p': {'default': None, 'type': float},
     'cluster_selection_method': {'default': 'eom', 'type': str},
-    'allow_single_cluster': {'default': False, 'type': bool}
+    'allow_single_cluster': {'default': False, 'type': bool},
+    'metric_type': {'default': 'euclidean', 'type': str}
 }
 
 
@@ -38,26 +42,48 @@ def shape_reducer_hdbscan(data_by_tool, **kwargs):
     ----------
     data_by_tool : dict
         A dictionary returned by :meth:`process_data`
-    kwrgs :
+    metric_type : str
+        Either "euclidean" to use a euclidean metric in the N-dimension shape parameter space
+        or "IoU" for the intersection of union metric based on shape overlap.  The IoU metric
+        can only be used with the following shape:
+
+        * rectangle
+        * rotateRectangle
+        * circle
+        * ellipse
+
+    kwargs :
         `See HDBSCAN <http://hdbscan.readthedocs.io/en/latest/api.html#hdbscan>`_
 
     Returns
     -------
     reduction : dict
-        A dictinary with the following keys for each frame
+        A dictionary with the following keys for each frame
 
-        * `tool*_<shape>_<param>` : A list of **all** `param` for the `sahpe` drawn with `tool*`
+        * `tool*_<shape>_<param>` : A list of **all** `param` for the `shape` drawn with `tool*`
         * `tool*_cluster_labels` : A list of cluster labels for **all** shapes drawn with `tool*`
         * `tool*_cluster_probabilities`: A list of cluster probabilities for **all** points drawn with `tool*`
-        * `tool*_clusters_persistance`: A mesure for how persistent each **cluster** is (1.0 = stable, 0.0 = unstable)
+        * `tool*_clusters_persistance`: A measure for how persistent each **cluster** is (1.0 = stable, 0.0 = unstable)
         * `tool*_clusters_count` : The number of points in each **cluster** found
         * `tool*_clusters_<param>` : The `param` value for each **cluster** found
+
+        If the "IoU" metric type is used there is also
+
+        * `tool*_clusters_sigma` : The standard deviation of the average shape under the IoU metric
     '''
     shape = data_by_tool.pop('shape')
     shape_params = SHAPE_LUT[shape]
+    metric_type = kwargs.pop('metric_type', 'euclidean').lower()
     symmetric = data_by_tool.pop('symmetric')
-    metric, avg = get_shape_metric_and_avg(shape, symmetric=symmetric)
-    kwargs['metric'] = metric
+    if metric_type == 'euclidean':
+        metric, avg = get_shape_metric_and_avg(shape, symmetric=symmetric)
+        kwargs['metric'] = metric
+    elif metric_type == 'iou':
+        kwargs['metric'] = IoU_metric
+        kwargs['shape'] = shape
+        avg = average_shape_IoU
+    else:
+        raise ValueError('metric_type must be either "euclidean" or "IoU".')
     clusters = OrderedDict()
     for frame, frame_data in data_by_tool.items():
         clusters[frame] = OrderedDict()
@@ -65,7 +91,7 @@ def shape_reducer_hdbscan(data_by_tool, **kwargs):
             loc = np.array(loc_list)
             if len(shape_params) == 1:
                 loc = loc.reshape(-1, 1)
-            # orignal data points in order used by cluster code
+            # original data points in order used by cluster code
             for pdx, param in enumerate(shape_params):
                 clusters[frame]['{0}_{1}_{2}'.format(tool, shape, param)] = loc[:, pdx].tolist()
             # default each point in no cluster
@@ -83,7 +109,11 @@ def shape_reducer_hdbscan(data_by_tool, **kwargs):
                         # number of points in the cluster
                         clusters[frame].setdefault('{0}_clusters_count'.format(tool), []).append(int(idx.sum()))
                         # mean of the cluster
-                        k_loc = avg(loc[idx])
+                        if metric_type == 'euclidean':
+                            k_loc = avg(loc[idx])
+                        elif metric_type == 'iou':
+                            k_loc, sigma = avg(loc[idx], shape)
+                            clusters[frame].setdefault('{0}_clusters_sigma'.format(tool), []).append(float(sigma))
                         for pdx, param in enumerate(shape_params):
                             clusters[frame].setdefault('{0}_clusters_{1}'.format(tool, param), []).append(float(k_loc[pdx]))
     return clusters
