@@ -15,7 +15,7 @@ class PathType(object):
             None: don't care
         dash_ok: whether to allow "-" as stdin/stdout
         '''
-        assert type in ('file', 'dir', 'symlink', None) or hasattr(type, '__call__')
+        assert type in ('file', 'dir', 'symlink', None) or callable(type)
         self._type = type
 
     def __call__(self, string):
@@ -29,7 +29,7 @@ class PathType(object):
             if not os.path.isfile(string):
                 raise err("path is not a file: '{0}'".format(string))
         elif self._type == 'symlink':
-            if not os.path.symlink(string):
+            if not os.path.islink(string):
                 raise err("path is not a symlink: '{0}'".format(string))
         elif self._type == 'dir':
             if not os.path.isdir(string):
