@@ -276,7 +276,7 @@ reduced_data = {
             'clusters_y': [297.0990905761719, 280.3498840332031],
             'consensus_score': 3.0,
             'consensus_text': 'Here are some test',
-            'line_slope': 358.894,
+            'line_slope': -1.1059999999999945,
             'number_views': 3,
             'user_ids': [1, 2, 3],
             'extract_index': [2, 0, 3],
@@ -297,7 +297,7 @@ reduced_data = {
             'clusters_y': [402.3798522949219, 395.2015686035156],
             'consensus_score': 3.0,
             'consensus_text': 'words on a page.',
-            'line_slope': 358.894,
+            'line_slope': -1.1059999999999945,
             'number_views': 3,
             'user_ids': [1, 2, 3],
             'extract_index': [0, 1, 2],
@@ -318,7 +318,7 @@ reduced_data = {
             'clusters_y': [287.5281066894531, 270.7789001464844],
             'consensus_score': 3.0,
             'consensus_text': 'There are two columns',
-            'line_slope': 358.894,
+            'line_slope': -1.1059999999999945,
             'number_views': 3,
             'user_ids': [1, 2, 3],
             'extract_index': [4, 4, 7],
@@ -337,7 +337,7 @@ reduced_data = {
             'clusters_y': [390.4161071777344, 373.6669006347656],
             'consensus_score': 3.0,
             'consensus_text': 'of text.',
-            'line_slope': 358.894,
+            'line_slope': -1.1059999999999945,
             'number_views': 3,
             'user_ids': [1, 2, 3],
             'extract_index': [5, 5, 5],
@@ -357,7 +357,7 @@ reduced_data = {
             'clusters_y': [536.37353515625, 131.99972534179688],
             'consensus_score': 3.0,
             'consensus_text': 'There is this',
-            'line_slope': 320.143,
+            'line_slope': -39.85700000000003,
             'number_views': 3,
             'user_ids': [1, 2, 3],
             'extract_index': [1, 6, 4],
@@ -377,7 +377,7 @@ reduced_data = {
             'clusters_y': [543.5517578125, 127.21426391601562],
             'consensus_score': 2.6666666666666665,
             'consensus_text': 'text as well',
-            'line_slope': 320.143,
+            'line_slope': -39.85700000000003,
             'number_views': 3,
             'user_ids': [1, 2, 3],
             'extract_index': [3, 7, 6],
@@ -396,7 +396,7 @@ reduced_data = {
             'clusters_y': [483.7331237792969, 67.39566040039062],
             'consensus_score': 3.0,
             'consensus_text': 'This looks like',
-            'line_slope': 320.143,
+            'line_slope': -39.85700000000003,
             'number_views': 3,
             'user_ids': [1, 2, 3],
             'extract_index': [6, 2, 0],
@@ -416,7 +416,7 @@ reduced_data = {
             'clusters_y': [526.802490234375, 155.92721557617188],
             'consensus_score': 3.0,
             'consensus_text': 'a big mess',
-            'line_slope': 320.143,
+            'line_slope': -39.85700000000003,
             'number_views': 3,
             'user_ids': [1, 2, 3],
             'extract_index': [7, 3, 1],
@@ -437,7 +437,7 @@ reduced_data = {
             'clusters_y': [700, 10],
             'consensus_score': 1.0,
             'consensus_text': 'not in a cluster',
-            'line_slope': 214.875,
+            'line_slope': -145.125,
             'number_views': 1,
             'user_ids': [None],
             'extract_index': [0],
@@ -761,7 +761,7 @@ reduced_data_no_length = {
         'max_eps': None,
         'xi': 0.05,
         'angle_eps': 30.0,
-        'gutter_eps': 150.0,
+        'gutter_eps': 300.0,
         'low_consensus_threshold': 3.0,
         'min_line_length': 0.0,
         'minimum_views': 5
