@@ -45,7 +45,8 @@ extracted_data = [
                 -0.23999309197815955,
                 -40.103966913878772,
                 -39.504439692518773
-            ]
+            ],
+            'gold_standard': False
         }
     },
     {
@@ -91,12 +92,14 @@ extracted_data = [
                 -1.9350479072142399,
                 -40.214619322353997,
                 -40.655937635767046
-            ]
+            ],
+            'gold_standard': False
         },
         'frame1': {
             'points': {'x': [[1, 180, 250]], 'y': [[1, 1, 1]]},
             'text': [['page', '2']],
-            'slope': [0]
+            'slope': [0],
+            'gold_standard': False
         }
     },
     {
@@ -142,7 +145,8 @@ extracted_data = [
                 -39.400653706482863,
                 -3.503541802690775,
                 -2.4681237681723815
-            ]
+            ],
+            'gold_standard': False
         }
     },
     {
@@ -188,12 +192,14 @@ extracted_data = [
                 -1.8257636189450075,
                 -39.334667288762937,
                 -1.122924085203026
-            ]
+            ],
+            'gold_standard': True
         },
         'frame1': {
             'points': {'x': [[1.1, 180.1, 251]], 'y': [[0.9, 0.9, 0.9]]},
             'text': [['page', '2']],
-            'slope': [0]
+            'slope': [0],
+            'gold_standard': True
         }
     },
     {
@@ -247,19 +253,33 @@ extracted_data = [
                 -33.996461321522638,
                 -1.7356948677716408,
                 -38.990998547208093
-            ]
+            ],
+            'gold_standard': False
         }
     },
     {
         'frame2': {
             'points': {'x': [[1, 180, 250]], 'y': [[1, 1, 1]]},
             'text': [['some', 'words']],
-            'slope': [0]
+            'slope': [0],
+            'gold_standard': False
         }
     },
     {}
 ]
 
+kwargs_extra_data = {
+    'user_id': [
+        1,
+        2,
+        3,
+        None,
+        5,
+        None,
+        7
+    ]
+}
+
 processed_data = {
     'frame0': {
         'x': [
@@ -437,6 +457,94 @@ processed_data = {
             -33.996461321522638,
             -1.7356948677716408,
             -38.990998547208093
+        ],
+        'gold_standard': [
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            True,
+            True,
+            True,
+            True,
+            True,
+            True,
+            True,
+            True,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False
+        ],
+        'data_index': [
+            0,
+            0,
+            0,
+            0,
+            0,
+            0,
+            0,
+            0,
+            1,
+            1,
+            1,
+            1,
+            1,
+            1,
+            1,
+            1,
+            2,
+            2,
+            2,
+            2,
+            2,
+            2,
+            2,
+            2,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4
         ]
     },
     'frame1': {
@@ -455,6 +563,14 @@ processed_data = {
         'slope': [
             0,
             0
+        ],
+        'gold_standard': [
+            False,
+            True
+        ],
+        'data_index': [
+            1,
+            3
         ]
     },
     'frame2': {
@@ -464,12 +580,25 @@ processed_data = {
         'y': [
             [1, 1, 1]
         ],
-        'text': [['some', 'words']],
-        'slope': [0]
+        'text': [
+            ['some', 'words']
+        ],
+        'slope': [
+            0
+        ],
+        'gold_standard': [
+            False
+        ],
+        'data_index': [
+            5
+        ]
     }
 }
 
 reduced_data = {
+    'reducer': 'poly_line_text_reducer',
+    'low_consensus_lines': 5,
+    'transcribed_lines': 10,
     'frame0': [
         {
             'clusters_x': [
@@ -495,9 +624,15 @@ reduced_data = {
             ],
             'number_views': 7,
             'consensus_score': 4.0,
+            'consensus_text': 'Here are some test',
             'gutter_label': 0,
             'line_slope': -1.5696676279703352,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, False, True, False, False],
+            'user_ids': [1, 2, 3, 3, None, 5, 5],
+            'extract_index': [2, 0, 0, 1, 3, 2, 8],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -523,9 +658,15 @@ reduced_data = {
             ],
             'number_views': 5,
             'consensus_score': 3.5,
+            'consensus_text': 'words on a page.',
             'gutter_label': 0,
             'line_slope': -1.5696676279703352,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, True, False],
+            'user_ids': [1, 2, 3, None, 5],
+            'extract_index': [0, 1, 6, 2, 3],
+            'low_consensus': True,
+            'flagged': True
         },
         {
             'clusters_x': [
@@ -551,9 +692,15 @@ reduced_data = {
             ],
             'number_views': 6,
             'consensus_score': 4.25,
+            'consensus_text': 'There are two columns',
             'gutter_label': 1,
             'line_slope': -1.5696676279703352,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, True, False, False],
+            'user_ids': [1, 2, 3, None, 5, 5],
+            'extract_index': [4, 4, 2, 7, 0, 1],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -573,9 +720,15 @@ reduced_data = {
             ],
             'number_views': 4,
             'consensus_score': 3.5,
+            'consensus_text': 'of text.',
             'gutter_label': 1,
             'line_slope': -1.5696676279703352,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, True],
+            'user_ids': [1, 2, 3, None],
+            'extract_index': [5, 5, 7, 5],
+            'low_consensus': True,
+            'flagged': True
         },
         {
             'clusters_x': [
@@ -598,9 +751,15 @@ reduced_data = {
             ],
             'number_views': 5,
             'consensus_score': 4.0,
+            'consensus_text': 'There is this',
             'gutter_label': 0,
             'line_slope': -40.020044794251575,
-            'slope_label': 1
+            'slope_label': 1,
+            'gold_standard': [False, False, False, True, False],
+            'user_ids': [1, 2, 3, None, 5],
+            'extract_index': [1, 6, 5, 4, 7],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -623,9 +782,15 @@ reduced_data = {
             ],
             'number_views': 4,
             'consensus_score': 3.0,
+            'consensus_text': 'text as well',
             'gutter_label': 0,
             'line_slope': -40.020044794251575,
-            'slope_label': 1
+            'slope_label': 1,
+            'gold_standard': [False, False, True, False],
+            'user_ids': [1, 2, None, 5],
+            'extract_index': [3, 7, 6, 4],
+            'low_consensus': True,
+            'flagged': True
         },
         {
             'clusters_x': [
@@ -648,9 +813,15 @@ reduced_data = {
             ],
             'number_views': 5,
             'consensus_score': 4.0,
+            'consensus_text': 'This looks like',
             'gutter_label': 1,
             'line_slope': -40.020044794251575,
-            'slope_label': 1
+            'slope_label': 1,
+            'gold_standard': [False, False, False, True, False],
+            'user_ids': [1, 2, 3, None, 5],
+            'extract_index': [6, 2, 4, 0, 6],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -673,9 +844,15 @@ reduced_data = {
             ],
             'number_views': 6,
             'consensus_score': 4.333333333333333,
+            'consensus_text': 'a big mess',
             'gutter_label': 1,
             'line_slope': -40.020044794251575,
-            'slope_label': 1
+            'slope_label': 1,
+            'gold_standard': [False, False, False, True, False, False],
+            'user_ids': [1, 2, 3, None, 5, 5],
+            'extract_index': [7, 3, 3, 1, 5, 9],
+            'low_consensus': False,
+            'flagged': False
         }
     ],
     'frame1': [
@@ -697,17 +874,23 @@ reduced_data = {
             ],
             'number_views': 2,
             'consensus_score': 2.0,
+            'consensus_text': 'page 2',
             'gutter_label': 0,
             'line_slope': 0.0,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, True],
+            'user_ids': [2, None],
+            'extract_index': [0, 0],
+            'low_consensus': True,
+            'flagged': True
         }
     ],
     'frame2': [
         {
             'clusters_x': [
-                1,
-                180,
-                250
+                1.0,
+                180.0,
+                250.0
             ],
             'clusters_y': [
                 1.0,
@@ -721,11 +904,29 @@ reduced_data = {
             ],
             'number_views': 1,
             'consensus_score': 1.0,
+            'consensus_text': 'some words',
             'gutter_label': 0,
             'line_slope': 0.0,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False],
+            'user_ids': [None],
+            'extract_index': [0],
+            'low_consensus': True,
+            'flagged': True
         }
-    ]
+    ],
+    'parameters': {
+        'eps_slope': 25.0,
+        'eps_line': 40.0,
+        'eps_word': 50.0,
+        'gutter_tol': 0.0,
+        'min_samples': 1,
+        'dot_freq': 'word',
+        'min_word_count': 1,
+        'low_consensus_threshold': 4.0,
+        'process_by_line': False,
+        'minimum_views': 5
+    }
 }
 
 TestPLTReducer = ReducerTest(
@@ -736,17 +937,21 @@ TestPLTReducer = ReducerTest(
     reduced_data,
     'Test poly-line-text reducer by word',
     okwargs={
-        'metric': 'euclidean',
-        'gutter_tol': 0,
+        'gutter_tol': 0.0
     },
     kwargs={
-        'eps_slope': 25,
-        'eps_line': 40,
-        'eps_word': 50,
+        'eps_slope': 25.0,
+        'eps_line': 40.0,
+        'eps_word': 50.0,
         'min_samples': 1,
         'dot_freq': 'word',
-        'min_word_count': 1
-    }
+        'min_word_count': 1,
+        'low_consensus_threshold': 4.0,
+        'minimum_views': 5
+    },
+    network_kwargs=kwargs_extra_data,
+    output_kwargs=True,
+    test_name='TestPLTReducer'
 )
 
 processed_data_by_line = {
@@ -926,6 +1131,94 @@ processed_data_by_line = {
             -33.996461321522638,
             -1.7356948677716408,
             -38.990998547208093
+        ],
+        'gold_standard': [
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            True,
+            True,
+            True,
+            True,
+            True,
+            True,
+            True,
+            True,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False
+        ],
+        'data_index': [
+            0,
+            0,
+            0,
+            0,
+            0,
+            0,
+            0,
+            0,
+            1,
+            1,
+            1,
+            1,
+            1,
+            1,
+            1,
+            1,
+            2,
+            2,
+            2,
+            2,
+            2,
+            2,
+            2,
+            2,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4
         ]
     },
     'frame1': {
@@ -944,6 +1237,14 @@ processed_data_by_line = {
         'slope': [
             0,
             0
+        ],
+        'gold_standard': [
+            False,
+            True
+        ],
+        'data_index': [
+            1,
+            3
         ]
     },
     'frame2': {
@@ -958,11 +1259,20 @@ processed_data_by_line = {
         ],
         'slope': [
             0
+        ],
+        'gold_standard': [
+            False
+        ],
+        'data_index': [
+            5
         ]
     }
 }
 
 reduced_data_by_line = {
+    'reducer': 'poly_line_text_reducer',
+    'low_consensus_lines': 5,
+    'transcribed_lines': 10,
     'frame0': [
         {
             'clusters_x': [
@@ -981,9 +1291,15 @@ reduced_data_by_line = {
             ],
             'number_views': 7,
             'consensus_score': 4.0,
+            'consensus_text': 'Here are some test',
             'gutter_label': 0,
             'line_slope': -1.5696676279703352,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, False, True, False, False],
+            'user_ids': [1, 2, 3, 3, None, 5, 5],
+            'extract_index': [2, 0, 0, 1, 3, 2, 8],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -1002,9 +1318,15 @@ reduced_data_by_line = {
             ],
             'number_views': 5,
             'consensus_score': 3.5,
+            'consensus_text': 'words on a page.',
             'gutter_label': 0,
             'line_slope': -1.5696676279703352,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, True, False],
+            'user_ids': [1, 2, 3, None, 5],
+            'extract_index': [0, 1, 6, 2, 3],
+            'low_consensus': True,
+            'flagged': True
         },
         {
             'clusters_x': [
@@ -1023,9 +1345,15 @@ reduced_data_by_line = {
             ],
             'number_views': 6,
             'consensus_score': 4.25,
+            'consensus_text': 'There are two columns',
             'gutter_label': 1,
             'line_slope': -1.5696676279703352,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, True, False, False],
+            'user_ids': [1, 2, 3, None, 5, 5],
+            'extract_index': [4, 4, 2, 7, 0, 1],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -1042,9 +1370,15 @@ reduced_data_by_line = {
             ],
             'number_views': 4,
             'consensus_score': 3.5,
+            'consensus_text': 'of text.',
             'gutter_label': 1,
             'line_slope': -1.5696676279703352,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, True],
+            'user_ids': [1, 2, 3, None],
+            'extract_index': [5, 5, 7, 5],
+            'low_consensus': True,
+            'flagged': True
         },
         {
             'clusters_x': [
@@ -1062,9 +1396,15 @@ reduced_data_by_line = {
             ],
             'number_views': 5,
             'consensus_score': 4.0,
+            'consensus_text': 'There is this',
             'gutter_label': 0,
             'line_slope': -40.020044794251575,
-            'slope_label': 1
+            'slope_label': 1,
+            'gold_standard': [False, False, False, True, False],
+            'user_ids': [1, 2, 3, None, 5],
+            'extract_index': [1, 6, 5, 4, 7],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -1082,9 +1422,15 @@ reduced_data_by_line = {
             ],
             'number_views': 4,
             'consensus_score': 3.0,
+            'consensus_text': 'text as well',
             'gutter_label': 0,
             'line_slope': -40.020044794251575,
-            'slope_label': 1
+            'slope_label': 1,
+            'gold_standard': [False, False, True, False],
+            'user_ids': [1, 2, None, 5],
+            'extract_index': [3, 7, 6, 4],
+            'low_consensus': True,
+            'flagged': True
         },
         {
             'clusters_x': [
@@ -1102,9 +1448,15 @@ reduced_data_by_line = {
             ],
             'number_views': 5,
             'consensus_score': 4.0,
+            'consensus_text': 'This looks like',
             'gutter_label': 1,
             'line_slope': -40.020044794251575,
-            'slope_label': 1
+            'slope_label': 1,
+            'gold_standard': [False, False, False, True, False],
+            'user_ids': [1, 2, 3, None, 5],
+            'extract_index': [6, 2, 4, 0, 6],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -1122,9 +1474,15 @@ reduced_data_by_line = {
             ],
             'number_views': 6,
             'consensus_score': 4.333333333333333,
+            'consensus_text': 'a big mess',
             'gutter_label': 1,
             'line_slope': -40.020044794251575,
-            'slope_label': 1
+            'slope_label': 1,
+            'gold_standard': [False, False, False, True, False, False],
+            'user_ids': [1, 2, 3, None, 5, 5],
+            'extract_index': [7, 3, 3, 1, 5, 9],
+            'low_consensus': False,
+            'flagged': False
         }
     ],
     'frame1': [
@@ -1143,26 +1501,50 @@ reduced_data_by_line = {
             ],
             'number_views': 2,
             'consensus_score': 2.0,
+            'consensus_text': 'page 2',
             'gutter_label': 0,
             'line_slope': 0.0,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, True],
+            'user_ids': [2, None],
+            'extract_index': [0, 0],
+            'low_consensus': True,
+            'flagged': True
         }
     ],
     'frame2': [
         {
-            'clusters_x': [1, 250],
-            'clusters_y': [1, 1],
+            'clusters_x': [1.0, 250.0],
+            'clusters_y': [1.0, 1.0],
             'clusters_text': [
                 ['some'],
                 ['words']
             ],
             'number_views': 1,
             'consensus_score': 1.0,
+            'consensus_text': 'some words',
             'gutter_label': 0,
             'line_slope': 0.0,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False],
+            'user_ids': [None],
+            'extract_index': [0],
+            'low_consensus': True,
+            'flagged': True
         }
-    ]
+    ],
+    'parameters': {
+        'eps_slope': 25.0,
+        'eps_line': 40.0,
+        'eps_word': 50.0,
+        'gutter_tol': 0.0,
+        'min_samples': 1,
+        'dot_freq': 'line',
+        'min_word_count': 1,
+        'low_consensus_threshold': 4.0,
+        'process_by_line': True,
+        'minimum_views': 5
+    }
 }
 
 TestPLTReducerByLine = ReducerTest(
@@ -1173,23 +1555,30 @@ TestPLTReducerByLine = ReducerTest(
     reduced_data_by_line,
     'Test poly-line-text reducer by line',
     okwargs={
-        'metric': 'euclidean',
-        'gutter_tol': 0
+        'gutter_tol': 0.0
     },
     pkwargs={
         'process_by_line': True
     },
     kwargs={
-        'eps_slope': 25,
-        'eps_line': 40,
-        'eps_word': 50,
+        'eps_slope': 25.0,
+        'eps_line': 40.0,
+        'eps_word': 50.0,
         'min_samples': 1,
         'dot_freq': 'line',
-        'min_word_count': 1
-    }
+        'min_word_count': 1,
+        'low_consensus_threshold': 4.0,
+        'minimum_views': 5
+    },
+    network_kwargs=kwargs_extra_data,
+    output_kwargs=True,
+    test_name='TestPLTReducerByLine'
 )
 
 reduced_data_min_word = {
+    'reducer': 'poly_line_text_reducer',
+    'low_consensus_lines': 2,
+    'transcribed_lines': 10,
     'frame0': [
         {
             'clusters_x': [
@@ -1208,9 +1597,15 @@ reduced_data_min_word = {
             ],
             'number_views': 7,
             'consensus_score': 4.333333333333333,
+            'consensus_text': 'are some test',
             'gutter_label': 0,
             'line_slope': -1.5696676279703352,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, False, True, False, False],
+            'user_ids': [1, 2, 3, 3, None, 5, 5],
+            'extract_index': [2, 0, 0, 1, 3, 2, 8],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -1229,9 +1624,15 @@ reduced_data_min_word = {
             ],
             'number_views': 5,
             'consensus_score': 5.0,
+            'consensus_text': 'words',
             'gutter_label': 0,
             'line_slope': -1.5696676279703352,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, True, False],
+            'user_ids': [1, 2, 3, None, 5],
+            'extract_index': [0, 1, 6, 2, 3],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -1250,9 +1651,15 @@ reduced_data_min_word = {
             ],
             'number_views': 6,
             'consensus_score': 4.25,
+            'consensus_text': 'There are two columns',
             'gutter_label': 1,
             'line_slope': -1.5696676279703352,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, True, False, False],
+            'user_ids': [1, 2, 3, None, 5, 5],
+            'extract_index': [4, 4, 2, 7, 0, 1],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -1269,9 +1676,15 @@ reduced_data_min_word = {
             ],
             'number_views': 4,
             'consensus_score': 4.0,
+            'consensus_text': 'text.',
             'gutter_label': 1,
             'line_slope': -1.5696676279703352,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, True],
+            'user_ids': [1, 2, 3, None],
+            'extract_index': [5, 5, 7, 5],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -1289,9 +1702,15 @@ reduced_data_min_word = {
             ],
             'number_views': 5,
             'consensus_score': 4.5,
+            'consensus_text': 'is this',
             'gutter_label': 0,
             'line_slope': -40.020044794251575,
-            'slope_label': 1
+            'slope_label': 1,
+            'gold_standard': [False, False, False, True, False],
+            'user_ids': [1, 2, 3, None, 5],
+            'extract_index': [1, 6, 5, 4, 7],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -1309,9 +1728,15 @@ reduced_data_min_word = {
             ],
             'number_views': 4,
             'consensus_score': 4.0,
+            'consensus_text': 'as',
             'gutter_label': 0,
             'line_slope': -40.020044794251575,
-            'slope_label': 1
+            'slope_label': 1,
+            'gold_standard': [False, False, True, False],
+            'user_ids': [1, 2, None, 5],
+            'extract_index': [3, 7, 6, 4],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -1329,9 +1754,15 @@ reduced_data_min_word = {
             ],
             'number_views': 5,
             'consensus_score': 4.5,
+            'consensus_text': 'looks like',
             'gutter_label': 1,
             'line_slope': -40.020044794251575,
-            'slope_label': 1
+            'slope_label': 1,
+            'gold_standard': [False, False, False, True, False],
+            'user_ids': [1, 2, 3, None, 5],
+            'extract_index': [6, 2, 4, 0, 6],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_x': [
@@ -1349,9 +1780,15 @@ reduced_data_min_word = {
             ],
             'number_views': 6,
             'consensus_score': 4.333333333333333,
+            'consensus_text': 'a big mess',
             'gutter_label': 1,
             'line_slope': -40.020044794251575,
-            'slope_label': 1
+            'slope_label': 1,
+            'gold_standard': [False, False, False, True, False, False],
+            'user_ids': [1, 2, 3, None, 5, 5],
+            'extract_index': [7, 3, 3, 1, 5, 9],
+            'low_consensus': False,
+            'flagged': False
         }
     ],
     'frame1': [
@@ -1370,26 +1807,50 @@ reduced_data_min_word = {
             ],
             'number_views': 2,
             'consensus_score': 0.0,
+            'consensus_text': '',
             'gutter_label': 0,
             'line_slope': 0.0,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, True],
+            'user_ids': [2, None],
+            'extract_index': [0, 0],
+            'low_consensus': True,
+            'flagged': True
         }
     ],
     'frame2': [
         {
-            'clusters_x': [1, 250],
-            'clusters_y': [1, 1],
+            'clusters_x': [1.0, 250.0],
+            'clusters_y': [1.0, 1.0],
             'clusters_text': [
                 [''],
                 ['']
             ],
             'number_views': 1,
             'consensus_score': 0.0,
+            'consensus_text': '',
             'gutter_label': 0,
             'line_slope': 0.0,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False],
+            'user_ids': [None],
+            'extract_index': [0],
+            'low_consensus': True,
+            'flagged': True
         }
-    ]
+    ],
+    'parameters': {
+        'eps_slope': 25.0,
+        'eps_line': 40.0,
+        'eps_word': 50.0,
+        'gutter_tol': 0.0,
+        'min_samples': 1,
+        'dot_freq': 'line',
+        'min_word_count': 4,
+        'low_consensus_threshold': 4.0,
+        'process_by_line': True,
+        'minimum_views': 5
+    }
 }
 
 TestPLTReducerWithMinWordCount = ReducerTest(
@@ -1400,18 +1861,107 @@ TestPLTReducerWithMinWordCount = ReducerTest(
     reduced_data_min_word,
     'Test poly-line-text reducer by line with a min word count',
     okwargs={
-        'metric': 'euclidean',
-        'gutter_tol': 0
+        'gutter_tol': 0.0
     },
     pkwargs={
         'process_by_line': True
     },
     kwargs={
-        'eps_slope': 25,
-        'eps_line': 40,
-        'eps_word': 50,
+        'eps_slope': 25.0,
+        'eps_line': 40.0,
+        'eps_word': 50.0,
         'min_samples': 1,
         'dot_freq': 'line',
-        'min_word_count': 4
+        'min_word_count': 4,
+        'low_consensus_threshold': 4,
+        'minimum_views': 5
+    },
+    network_kwargs=kwargs_extra_data,
+    output_kwargs=True,
+    test_name='TestPLTReducerWithMinWordCount'
+)
+
+# this is a real classification that happened on ASM
+extracted_data_no_length = [
+    {
+        'frame5': {
+            'points': {
+                'x': [
+                    [620.4314017895185, 620.4314017895185]
+                ],
+                'y': [
+                    [142.3093310609288, 142.3093310609288]
+                ]
+            },
+            'text': [
+                ['[ no content]']
+            ],
+            'slope': [0.0],
+            'gold_standard': False
+        }
     }
+]
+
+kwargs_extra_data_no_length = {
+    'user_id': [
+        1
+    ]
+}
+
+processed_data_no_length = {
+    'frame5': {
+        'data_index': [0],
+        'gold_standard': [False],
+        'slope': [0.0],
+        'text': [['[ no content]']],
+        'x': [[620.4314017895185, 620.4314017895185]],
+        'y': [[142.3093310609288, 142.3093310609288]]
+    }
+}
+
+reduced_data_no_length = {
+    'reducer': 'poly_line_text_reducer',
+    'low_consensus_lines': 0,
+    'transcribed_lines': 0,
+    'frame5': [],
+    'parameters': {
+        'eps_slope': 25.0,
+        'eps_line': 40.0,
+        'eps_word': 50.0,
+        'gutter_tol': 0.0,
+        'min_samples': 1,
+        'dot_freq': 'line',
+        'min_word_count': 1,
+        'low_consensus_threshold': 4.0,
+        'process_by_line': True,
+        'minimum_views': 5
+    }
+}
+
+TestPolyLTReducerNoLengthLine = ReducerTest(
+    poly_line_text_reducer,
+    process_data,
+    extracted_data_no_length,
+    processed_data_no_length,
+    reduced_data_no_length,
+    'Text poly-line-text reducer with a zero length line',
+    okwargs={
+        'gutter_tol': 0.0
+    },
+    pkwargs={
+        'process_by_line': True
+    },
+    kwargs={
+        'eps_slope': 25.0,
+        'eps_line': 40.0,
+        'eps_word': 50.0,
+        'min_samples': 1,
+        'dot_freq': 'line',
+        'min_word_count': 1,
+        'low_consensus_threshold': 4.0,
+        'minimum_views': 5
+    },
+    network_kwargs=kwargs_extra_data_no_length,
+    output_kwargs=True,
+    test_name='TestPolyLTReducerNoLengthLine'
 )
