@@ -1,5 +1,6 @@
 from panoptes_aggregation.reducers.shape_reducer_dbscan import process_data as process_data_dbscan, shape_reducer_dbscan
 from panoptes_aggregation.reducers.shape_reducer_hdbscan import process_data as process_data_hdbscan, shape_reducer_hdbscan
+from panoptes_aggregation.reducers.shape_reducer_optics import process_data as process_data_optics, shape_reducer_optics
 from .base_test_class import ReducerTest
 import copy
 
@@ -165,6 +166,21 @@ TestShapeReducerEllipse = ReducerTest(
     test_name='TestShapeReducerEllipse'
 )
 
+TestShapeReducerEllipseOptics = ReducerTest(
+    shape_reducer_optics,
+    process_data_optics,
+    extracted_data,
+    processed_data,
+    reduced_data,
+    'Test shape ellipse reducer with OPTICS',
+    network_kwargs=kwargs_extra_data,
+    pkwargs={'shape': 'ellipse'},
+    kwargs={
+        'min_samples': 2
+    },
+    test_name='TestShapeReducerEllipseOptics'
+)
+
 reduced_data_hdbscan = copy.deepcopy(reduced_data)
 reduced_data_hdbscan['frame0']['T0_tool0_cluster_probabilities'] = [1.0, 1.0, 1.0, 1.0]
 reduced_data_hdbscan['frame0']['T0_tool0_clusters_persistance'] = [0.9868693567140278, 0.9868693567140278]
