@@ -1,5 +1,6 @@
 from panoptes_aggregation.reducers.shape_reducer_dbscan import shape_reducer_dbscan
 from panoptes_aggregation.reducers.shape_reducer_hdbscan import shape_reducer_hdbscan
+from panoptes_aggregation.reducers.shape_reducer_optics import shape_reducer_optics
 from .base_test_class import ReducerTestNoProcessing
 import copy
 
@@ -107,6 +108,19 @@ TestShapeReducerFullHeightLine = ReducerTestNoProcessing(
     test_name='TestShapeReducerFullHeightLine'
 )
 
+TestShapeReducerFullHeightLineOptics = ReducerTestNoProcessing(
+    shape_reducer_optics,
+    extracted_data,
+    reduced_data,
+    'Test shape fullHeightLine reducer with OPTICS',
+    network_kwargs=kwargs_extra_data,
+    kwargs={
+        'min_samples': 2,
+        'shape': 'fullHeightLine'
+    },
+    test_name='TestShapeReducerFullHeightLineOptics'
+)
+
 reduced_data_hdbscan = copy.deepcopy(reduced_data)
 reduced_data_hdbscan['frame0']['T0_tool0_cluster_probabilities'] = [1, 1, 1, 1]
 reduced_data_hdbscan['frame0']['T0_tool0_clusters_persistance'] = [1, 1]
